/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, Thomas and Skopek, Jan (2015). Convergence or Continuity? 
  The Gender Gap in Household Labor After Retirement. In: Journal of 
  Marriage and Family.
  
  PROJECT MASTER FILE
 
  The syntax of the empirical analysis is divided into sub-files, each 
  of which completes a specific step in the analysis. 
  
  This master file runs each of these steps in the right order. 
  You can run the complete analysis by executing this file.
 
  The syntax for the project is split into the following steps:
  
  0-X) DATA PREPARATION (SOEP v.29)
  
	0-0) Preparing survey data
  
	0-1) Selecting the analytical sample
  
	0-2) Multiple imputation
  
  1-X) DATA ANALYSIS 
  
	1-0) Descriptive Tables
	   
	1-1) Fixed Effects Models
	   
 
  Detailed documentation can be found in the respective sub-files. 
  
  The configuration file 'config.do' defines important 
  settings (= paths) as well as various programs needed for the analysis. 
  Before executing any other do-file, this file should always run first. 

------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

// call the configuration file
run config 	

/*------------------------------------------------------------------------------
 ------------------------------------------------------------------------------
 
 0-X) DATA PREPARATION 
 
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

/*------------------------------------------------------------------------------
 0-0) Preparing the original survey data (SOEP v.29)
------------------------------------------------------------------------------*/
do 00_preparation.do

/*------------------------------------------------------------------------------
 0-1) Sample selection
------------------------------------------------------------------------------*/
do 01_sample.do

/*------------------------------------------------------------------------------
 0-2) Multiple imputation of missing values
------------------------------------------------------------------------------*/
do 02_imputation.do


/*------------------------------------------------------------------------------
 ------------------------------------------------------------------------------
 
 1-X) DATA ANALYSIS 
 
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

/*------------------------------------------------------------------------------
 1-0) Descriptive tables
	  
	  Table 1 - Number of Observations per Couple
	  Table 2 - Description and Coding of Analytical Variables
      Table 3 - Descriptive Statistics on Sample of Couples Across Phase of 
				Retirement and First Observation
------------------------------------------------------------------------------*/
do 10_descriptives.do

/*------------------------------------------------------------------------------
 1-1) Fixed Effects Models
 
      Table A1 - Fixed Effects Regression Models 
			 for Change in 12 Outcomes After 
			 Husband's Retirement.
			 
	  Figure 1 - Changes in Total Household Labor 
			 Across the Husband's Transition 
			 to Retirement.
			 
      Figure 2 - Changes in Routine Housework, 
			 Errands, and Repairs/Gardening 
			 Across Husbands's Transitions to
			 Retirement.
------------------------------------------------------------------------------*/
do 11_fixed_effects_models.do
